### Name: glmmBUGS
### Title: A function to run Generalised Linear Mixed Models in Bugs
### Aliases: glmmBUGS


### ** Examples
 
library(nlme)
data(Muscle)

muscleRagged = glmmBUGS(conc ~ length, data=Muscle, effects="Strip", family="gaussian")
startingValues = muscleRagged$startingValues

## Not run: 
##D source("getInits.R")
##D require(BRugs)
##D require(R2WinBUGS)  
##D muscleResult = bugs(muscleRagged$ragged, getInits, parameters.to.save = names(getInits()),
##D                 model.file="model.bug", n.chain=3, n.iter=1000, n.burnin=100, n.thin=10,
##D                              program="openbugs") 
## End(Not run)
 
data(muscleResult)

muscleParams = restoreParams(muscleResult, muscleRagged$ragged)  
summaryChain(muscleParams)
checkChain(muscleParams)


# a spatial example
## Not run: 
##D library(diseasemapping)
##D 
##D data(popdata)
##D data(casedata)
##D 
##D model = getRates(casedata, popdata, ~age*sex)
##D ontario = getSMR(popdata, model, casedata)
##D ontario = ontario@data[,c("CSDUID","observed","logExpected")]
##D 
##D library(spdep)
##D popDataAdjMat = poly2nb(popdata,row.names=as.character(popdata[["CSDUID"]]))
## End(Not run)

data(popDataAdjMat)
data(ontario)

forBugs = glmmBUGS(formula=observed + logExpected ~ 1,
  effects="CSDUID",   family="poisson", spatial=popDataAdjMat,
  data=ontario)

startingValues = forBugs$startingValues

source("getInits.R")

## Not run: 
##D ontarioResult = bugs(forBugs$ragged, getInits, 
##D   parameters.to.save = names(getInits()),
##D     model.file="model.bug", n.chain=3, n.iter=50, n.burnin=10, n.thin=2,
##D       program="winbugs", debug=T)
## End(Not run)

data(ontarioResult)

ontarioParams = restoreParams(ontarioResult, forBugs$ragged)

ontarioSummary = summaryChain(ontarioParams)

# posterior probability of having 10x excess risk
postProb = apply(ontarioParams$FittedRateCSDUID, 3, function(x) mean(x>10))
hist(postProb)

## Not run: 
##D 
##D ontario = mergeBugsData(popdata, ontarioSummary)
##D 
##D spplot(ontario, "FittedRateCSDUID.mean")
##D 
##D ontario = mergeBugsData(ontario, postProb, newcol="postProb", by.x="CSDUID")
##D spplot(ontario, "postProb")
##D 
##D 
## End(Not run)



